<?php

declare(strict_types=1);

require_once '../vendor/autoload.php';

require_once '../config.php';
require_once '../db/datasource.php';
require_once '../db/images.query.php';
require_once '../db/reviews.query.php';
require_once '../db/campgrounds.query.php';
require_once '../models/images.php';
require_once '../models/campground.php';
require_once '../utils/helper.php';

require_once 'cities.php';
require_once 'seedHelpers.php';

use db\ImageQuery;
use db\ReviewQuery;
use db\CampGroundQuery;
use models\CampGroundSchema;

$seedDB = function () {
    global $cities;
    global $descriptors;
    global $places;

    ImageQuery::deleteAll();
    ReviewQuery::deleteAll();
    CampGroundQuery::deleteAll();

    $sample1 = fn(array $array): string => toString($array[rand(0, count($array) - 1)]);
    $sample2 = fn(array $array): array => toAssocArray($array[rand(0, count($array) - 1)]);

    for ($i = 0; $i < 50; $i++) {

        $title = $sample1(toStrArray($descriptors)) . '・' . $sample1(toStrArray($places));
        $data = $sample2(toAssocArrArray($cities));
        ['prefecture' => $pref, 'city' => $city] = $data;
        $location = $pref . $city;
        $price = rand(1000, 3000);
        $camp = new CampGroundSchema;
        $camp->author = 'test';
        $camp->title = $title;
        $camp->location = $location;
        $camp->geometry = forwardGeocode($location);
        $image1 = 'assets/' . sprintf('%03d', rand(1, 101)) . '.png';
        $image2 = 'assets/' . sprintf('%03d', rand(1, 101)) . '.png';
        $images = [];
        if (file_exists('../' . $image1)) array_push($images, $image1);
        if (file_exists('../' . $image2)) array_push($images, $image2);
        $camp->addImages($images);
        $camp->description = '木曾路はすべて山の中である。あるところは岨づたいに行く崖の道であり、あるところは数十間の深さに臨む木曾川の岸であり、あるところは山の尾をめぐる谷の入り口である。一筋の街道はこの深い森林地帯を貫いていた。東ざかいの桜沢から、西の十曲峠まで、木曾十一宿はこの街道に添うて、二十二里余にわたる長い谿谷の間に散在していた。道路の位置も幾たびか改まったもので、古道はいつのまにか深い山間に埋もれた。';
        $camp->price = $price;
        CampGroundQuery::save($camp);
    }

    redirect('/campgrounds');
};

$seedDB();
